<?php

use humhub\modules\live\models\Live;
use humhub\modules\mail\models\forms\CreateMessage;
use humhub\modules\mail\models\forms\InviteParticipantForm;
use tests\codeception\_support\HumHubDbTestCase;
use humhub\modules\user\models\User;

class NotificationTest extends HumHubDbTestCase
{
    public function _before()
    {
        // Required in HumHub < 1.6.3
        Live::deleteAll();
        parent::_before(); // TODO: Change the autogenerated stub
    }

    /**
     * @param $title
     * @param $message
     * @param null $users
     * @param array $tags
     * @return CreateMessage
     * @throws Throwable
     */
    private function createMessage($title, $message, $users = null, $tags = [])
    {
        $this->becomeUser('User1');

        $message = new CreateMessage([
            'title' => $title,
            'message' => $message,
            'recipient' => $users,
            'tags' => $tags
        ]);

        $this->assertTrue($message->save());

        return $message;
    }

   public function testNotificationsAreSentWhenCreatingAMessage()
   {
       $user2 = User::findOne(['id' => 3]);

       $this->createMessage('First', 'First', [$user2->guid]);

       // Check mail should only be sent to
       $this->assertMailSent(1);
       $this->assertEqualsLastEmailSubject('New message from Peter Tester');
       $this->assertEqualsLastEmailTo($user2->email);
       $test = Live::find()->all();
       $this->assertCount(1,  Live::find()->where(['contentcontainer_id' => $user2->contentcontainer_id])->all());
   }

    public function testNotificationsAreSentAllRecepients()
    {
        $user2 = User::findOne(['id' => 3]);
        $user3 = User::findOne(['id' => 4]);


        $this->createMessage('First', 'First', [$user2->guid, $user3->guid]);

        // Check mail should only be sent to
        $this->assertMailSent(2);
        $this->assertEqualsLastEmailSubject('New message from Peter Tester');
        $this->assertEqualsLastEmailTo($user3->email);

        $test =  Live::find(['contentcontainer_id' => $user2->contentcontainer_id])->all();
        $test2 = unserialize($test[0]->serialized_data);
        $test3 = unserialize($test[1]->serialized_data);
        $this->assertCount(1,  Live::find()->where(['contentcontainer_id' => $user2->contentcontainer_id])->all());
        $this->assertCount(1,  Live::find()->where(['contentcontainer_id' => $user3->contentcontainer_id])->all());
    }

    public function testNotificationsAreSentAfterAddingParticipant()
    {
        $user2 = User::findOne(['id' => 3]);
        $message = $this->createMessage('First', 'First', [$user2->guid]);


        $user3 = User::findOne(['id' => 4]);
        $inviteForm = new InviteParticipantForm(['message' => $message->messageInstance, 'recipients' => [$user3->guid]]);
        $inviteForm->save();

        $this->assertSentEmail(2);
        $this->assertEqualsLastEmailSubject('New message from Peter Tester');
        $this->assertEqualsLastEmailTo($user3->email);
    }

    public function assertEqualsLastEmailTo($email)
    {
        $this->assertArrayHasKey($email, $this->getYiiModule()->grabLastSentEmail()->to);
    }
}